********************************************************************************
***THIS FILE GENERATES THE 2009 CCES ANALYSIS REPORTED IN***********************
***GERBER ET AL. (2011): CITIZENS' POLICY CONFIDENCE AND ELECTORAL PUNISHMENT***
********************************************************************************

clear
set memory 100m
set more off

use cces_replication.dta
qui include 02_sub01_performcces_recodes.do

 *************************
 * Table A2. Correlates of Willingness to Take Policy Positions	
 *************************
qui regress eval* pos_* conf_* imp_* rpos_* rparty_* posXRpos_* pidXRpid_* Zbothagree_* Conf_pid_* Conf_pos_* Conf_rpos_* Conf_rparty_* Conf_posXRpos_* Conf_pidXRpid_* Conf_Zbothagree_* Impt_pid_* Impt_pos_* Impt_rpos_* Impt_rparty_* Impt_posXRpos_* Impt_pidXRpid_* Impt_Zbothagree_* age age2 r_black r_hispanic r_other female pid5 educ income incomemis, robust
 gen inall=e(sample)
qui foreach i in teen ssex jobs bank {
 gen no_opinion_`i'=pos_`i'==0
}
gen no_opinion=no_opinion_teen+no_opinion_ssex+no_opinion_jobs+no_opinion_bank
reg no_opinion age age2 r_black r_hispanic r_other female pidcat_* educ income incomemis if inall==1, r
outreg age age2 r_black r_hispanic r_other female pidcat_* educ income incomemis using "tableA2_noopinion", se bracket tdec(3) replace ctitle("# of issues w/No Opinion (0-4)")
count if inall==1
local total_inall=r(N)

  file open myfile using "tableA2_noopinion.out", write append 
   file write myfile "" _n
   file write myfile "Number of non-opinions, % w/this number of non-opinions" _n
   forvalues n=0/4{
   count if no_opinion==`n' & inall==1
   local prop=round(r(N)/`total_inall'*100,.001)
   file write myfile "`n'" _tab "`prop'" _n
   }
  file close myfile

reg no_opinion age age2 r_black r_hispanic r_other female pidcat_* educ income incomemis if inall==1 [aw=v200], r
outreg age age2 r_black r_hispanic r_other female pidcat_* educ income incomemis using "tableA2_noopinion_weighted", se bracket tdec(3) replace 
tab no_opinion if inall==1 [aw=v200]

*** GENERATE DICHOTOMOUS AGREE/DISAGREE, CONFIDENCE, and IMPORTANCE VARIABLES
qui foreach i in teen ssex jobs bank {
gen dich_agree_`i'=(pos_`i'<0 & rpos_`i'<0)|(pos_`i'>0 & rpos_`i'>0)
replace dich_agree_`i'=. if pos_`i'==0
gen dich_pty_agree_`i'=(pid<-1 & rparty_`i'<0)|(pid>1 & rparty_`i'>0)
replace dich_pty_agree_`i'=. if abs(pid)<=1
gen dich_conf_`i'=(conf_`i'>.5) if conf_`i'!=. & conf_`i'!=.5
gen dich_imp_`i'=(imp_`i'>.5) if imp_`i'!=.
gen dich_conf_agree_`i'=dich_conf_`i'*dich_agree_`i'
gen dich_imp_agree_`i'=dich_imp_`i'*dich_agree_`i'
gen dich_conf_pty_agree_`i'=dich_conf_`i'*dich_pty_agree_`i'
gen dich_imp_pty_agree_`i'=dich_imp_`i'*dich_pty_agree_`i'
}

** SET CONTROL VARIABLES TO USE IN REGRESSIONS
local controlvars = "age age2 r_black r_hispanic r_other female pid5 educ income incomemis"

* Define policy labels to be used in output
tokenize `"" Teen Pregnancy"" Same Sex Marriage"" Job Creation"" Banking Regulation""'

** LOOP THROUGH POLICY AREAS
foreach i in teen ssex jobs bank {

 ************************
 *construct common sample
 ************************
 qui regress eval_`i' pos_`i' conf_`i' imp_`i' rpos_`i' rparty_`i' posXRpos_`i' pidXRpid_`i' Zbothagree_`i' Conf_pid_`i' Conf_pos_`i' Conf_rpos_`i' Conf_rparty_`i' Conf_posXRpos_`i' Conf_pidXRpid_`i' Conf_Zbothagree_`i' Impt_pid_`i' Impt_pos_`i' Impt_rpos_`i' Impt_rparty_`i' Impt_posXRpos_`i' Impt_pidXRpid_`i' Impt_Zbothagree_`i' `controlvars', robust
 gen insample_`i'=e(sample)

 *************************
 * For Tables 2 and A4, first include the code for the Teen Pregnancy issue (first columns)
 if "`i'"=="teen"{
 *************************
 *************************
 * Table 2. Bivariate Analysis: Effect of Policy Agreement on Representative Evaluation by Policy Confidence and Importance				
 *************************
 sum conf_`i' if insample_`i'==1
 local table2_conf="Confidence, "+string(r(mean))
 sum imp_`i' if insample_`i'==1
 local table2_imp="Importance, "+string(r(mean))

 *Simple CONFIDENCE x AGREEMENT interactions regressions 
 regress eval_`i' dich_conf_agree_`i' dich_conf_`i' dich_agree_`i' if insample_`i'==1
 lincom dich_agree_`i' 
 local table2_lconf="Low Confidence, "+string(r(estimate))
 lincom dich_agree_`i'+dich_conf_agree_`i'
 local table2_hconf="High Confidence, "+string(r(estimate))
 lincom dich_conf_agree_`i'
 local table2_dconf="Difference in Difference, "+string(r(estimate))
 local table2_diffp="p-value (two-tailed), "+string(ttail(r(df),(abs(r(estimate)/r(se))))*2)

 *Simple IMPORTANCE X AGREEMENT interactions regressions 
 regress eval_`i' dich_imp_agree_`i' dich_imp_`i' dich_agree_`i' if insample_`i'==1
 lincom dich_agree_`i' 
 local table2_limp="Low Importance, "+string(r(estimate))
 lincom dich_agree_`i'+dich_imp_agree_`i'
 local table2_himp="High Importance, "+string(r(estimate))
 lincom dich_imp_agree_`i'
 local table2_dimp="Difference in Difference, "+string(r(estimate))
 local table2_diffimpp="p-value (two-tailed), "+string(ttail(r(df),(abs(r(estimate)/r(se))))*2)

 *************************
 * Table A4. Effect of Party Agreement on Representative Evaluation by Policy Confidence and Importance				
 *************************
 *Simple CONFIDENCE x PARTY AGREEMENT interactions regressions 
 regress eval_`i' dich_conf_pty_agree_`i' dich_conf_`i' dich_pty_agree_`i' if insample_`i'==1
 lincom dich_pty_agree_`i' 
 local tableA4_lconf="Low Confidence, "+string(r(estimate))
 lincom dich_pty_agree_`i'+dich_conf_pty_agree_`i'
 local tableA4_hconf="High Confidence, "+string(r(estimate))
 lincom dich_conf_pty_agree_`i'
 local tableA4_dconf="Difference in Difference, "+string(r(estimate))
 local tableA4_diffp="p-value (two-tailed), "+string(ttail(r(df),(abs(r(estimate)/r(se))))*2)

 *Simple IMPORTANCE X PARTY AGREEMENT interactions regressions 
 regress eval_`i' dich_imp_pty_agree_`i' dich_imp_`i' dich_pty_agree_`i' if insample_`i'==1
 lincom dich_pty_agree_`i' 
 local tableA4_limp="Low Importance, "+string(r(estimate))
 lincom dich_pty_agree_`i'+dich_imp_pty_agree_`i'
 local tableA4_himp="High Importance, "+string(r(estimate))
 lincom dich_imp_pty_agree_`i'
 local tableA4_dimp="Difference in Difference, "+string(r(estimate))
 local tableA4_diffimpp="p-value (two-tailed), "+string(ttail(r(df),(abs(r(estimate)/r(se))))*2)

 } 
 *************************
 * Now Tables 2 and A4 for all of the other policies
 else{
 *************************
 *************************
 * Table 2. Bivariate Analysis: Effect of Policy Agreement on Representative Evaluation by Policy Confidence and Importance				
 *************************
 sum conf_`i' if insample_`i'==1
 local table2_conf="`table2_conf', "+string(r(mean))
 sum imp_`i' if insample_`i'==1
 local table2_imp="`table2_imp', "+string(r(mean))

 *Simple CONFIDENCE x AGREEMENT interactions regressions 
 regress eval_`i' dich_conf_agree_`i' dich_conf_`i' dich_agree_`i' if insample_`i'==1
 lincom dich_agree_`i' 
 local table2_lconf="`table2_lconf', "+string(r(estimate))
 lincom dich_agree_`i'+dich_conf_agree_`i'
 local table2_hconf="`table2_hconf', "+string(r(estimate))
 lincom dich_conf_agree_`i'
 local table2_dconf="`table2_dconf', "+string(r(estimate))
 local table2_diffp="`table2_diffp', "+string(ttail(r(df),(abs(r(estimate)/r(se))))*2)

 *Simple IMPORTANCE X AGREEMENT interactions regressions 
 regress eval_`i' dich_imp_agree_`i' dich_imp_`i' dich_agree_`i' if insample_`i'==1
 lincom dich_agree_`i' 
 local table2_limp="`table2_limp', "+string(r(estimate))
 lincom dich_agree_`i'+dich_imp_agree_`i'
 local table2_himp="`table2_himp', "+string(r(estimate))
 lincom dich_imp_agree_`i'
 local table2_dimp="`table2_dimp', "+string(r(estimate))
 local table2_diffimpp="`table2_diffimpp', "+string(ttail(r(df),(abs(r(estimate)/r(se))))*2)

 *************************
 * Table A4. Effect of Party Agreement on Representative Evaluation by Policy Confidence and Importance				
 *************************
 *Simple CONFIDENCE x AGREEMENT interactions regressions 
 regress eval_`i' dich_conf_pty_agree_`i' dich_conf_`i' dich_pty_agree_`i' if insample_`i'==1
 lincom dich_pty_agree_`i' 
 local tableA4_lconf="`tableA4_lconf', "+string(r(estimate))
 lincom dich_pty_agree_`i'+dich_conf_pty_agree_`i'
 local tableA4_hconf="`tableA4_hconf', "+string(r(estimate))
 lincom dich_conf_pty_agree_`i'
 local tableA4_dconf="`tableA4_dconf', "+string(r(estimate))
 local tableA4_diffp="`tableA4_diffp', "+string(ttail(r(df),(abs(r(estimate)/r(se))))*2)

 *Simple IMPORTANCE X AGREEMENT interactions regressions 
 regress eval_`i' dich_imp_pty_agree_`i' dich_imp_`i' dich_pty_agree_`i' if insample_`i'==1
 lincom dich_pty_agree_`i' 
 local tableA4_limp="`tableA4_limp', "+string(r(estimate))
 lincom dich_pty_agree_`i'+dich_imp_pty_agree_`i'
 local tableA4_himp="`tableA4_himp', "+string(r(estimate))
 lincom dich_imp_pty_agree_`i'
 local tableA4_dimp="`tableA4_dimp', "+string(r(estimate))
 local tableA4_diffimpp="`tableA4_diffimpp', "+string(ttail(r(df),(abs(r(estimate)/r(se))))*2)
 }
 *************************
 * WRITE TABLES 2, and A4 to CSVs
 *************************
 if "`i'"=="bank"{
  file open myfile using "table2_confimp_bivariate.csv", write replace 
   file write myfile "Average,Teen Pregnancy,Same Sex Marriage,Job Creation,Banking Regulation" _n
   file write myfile "`table2_conf'" _n
   file write myfile "`table2_imp'" _n
   file write myfile ",,,," _n
   file write myfile "Difference in Mean Evaluation (Policy Agreement - Policy Disagreement), Teen Pregnancy, Same Sex Marriage, Job Creation, Banking Regulation" _n
   file write myfile "`table2_hconf'" _n
   file write myfile "`table2_lconf'" _n
   file write myfile "`table2_dconf'" _n
   file write myfile "`table2_diffp'" _n
   file write myfile ",,,," _n
   file write myfile "`table2_himp'" _n
   file write myfile "`table2_limp'" _n
   file write myfile "`table2_dimp'" _n
   file write myfile "`table2_diffimpp'" _n
   file close myfile

  file open myfile using "tableA4_pty_confimp_bivariate.csv", write replace 
   file write myfile "Difference in Mean Evaluation (Party Agreement - Party Disagreement), Teen Pregnancy, Same Sex Marriage, Job Creation, Banking Regulation" _n
   file write myfile "`tableA4_hconf'" _n
   file write myfile "`tableA4_lconf'" _n
   file write myfile "`tableA4_dconf'" _n
   file write myfile "`tableA4_diffp'" _n
   file write myfile ",,,," _n
   file write myfile "`tableA4_himp'" _n
   file write myfile "`tableA4_limp'" _n
   file write myfile "`tableA4_dimp'" _n
   file write myfile "`tableA4_diffimpp'" _n
   file close myfile
  }

 ************************
 * Table 3. Effect of Party and Policy Agreement on Representative Evaluation by Variation in Confidence and Importance, OLS Regression				
 ************************
 regress eval_`i' pos_`i' conf_`i' imp_`i' rpos_`i' rparty_`i' posXRpos_`i' pidXRpid_`i' Conf_pid_`i' Conf_pos_`i' Conf_rpos_`i' Conf_rparty_`i' Conf_posXRpos_`i' Conf_pidXRpid_`i' Impt_pid_`i' Impt_pos_`i' Impt_rpos_`i' Impt_rparty_`i' Impt_posXRpos_`i' Impt_pidXRpid_`i' `controlvars' if insample_`i'==1, robust
 *outreg using "evals.out", se bracket tdec(3) append 
 if "`i'"=="teen" {
  outreg using "table3_base_models.out", 3aster se bracket tdec(3) replace 
 }
 else {
  outreg using "table3_base_models.out", 3aster se bracket tdec(3) append 
 }

 * agreement significant for all confidence values?
 lincom 2*(posXRpos_`i' + Conf_posXRpos_`i')
 local hconf_fx_`i'=r(estimate)
 local hconf_p_`i'=2*(ttail(r(df), r(estimate)/r(se)))
 lincom 2*(posXRpos_`i') + Conf_posXRpos_`i'
 local mconf_fx_`i'=r(estimate)
 local mconf_p_`i'=2*(ttail(r(df), r(estimate)/r(se)))
 lincom 2*(posXRpos_`i')
 local lconf_fx_`i'=r(estimate)
 local lconf_p_`i'=2*(ttail(r(df), r(estimate)/r(se)))

 ************************
 * Figure 1 DATA: Effect of Policy Agreement on Evaluation of Representative by Confidence Levels
 ************************
 if "`i'"=="bank"{
  file open myfile using "figure1_data.csv", write replace 
   file write myfile ",Teen Pregnancy,Same Sex Marriage,Job Creation,Banking Regulation" _n
   file write myfile "High Confidence (confidence=1), `hconf_fx_teen', `hconf_fx_ssex', `hconf_fx_jobs', `hconf_fx_bank'" _n
   file write myfile "Low Confidence (confidence=0), `lconf_fx_teen', `lconf_fx_ssex', `lconf_fx_jobs', `lconf_fx_bank'" _n
   file close myfile
 }

 ************************
 * Table 4. Robustness of Effect of Party and Policy Agreement on Representative Evaluation by Variation in Confidence and Importance, OLS Regression												
 ************************
 *with all interactions
 regress eval_`i' pos_`i' conf_`i' imp_`i' rpos_`i' rparty_`i' posXRpos_`i' pidXRpid_`i' Conf_pid_`i' Conf_pos_`i' Conf_rpos_`i' Conf_rparty_`i' Conf_posXRpos_`i' Conf_pidXRpid_`i' Impt_pid_`i' Impt_pos_`i' Impt_rpos_`i' Impt_rparty_`i' Impt_posXRpos_`i' Impt_pidXRpid_`i' Q*`i' `controlvars' if insample_`i'==1, robust
 if "`i'"=="teen" {
  outreg pos_`i' conf_`i' imp_`i' rpos_`i' rparty_`i' posXRpos_`i' pidXRpid_`i' Conf_pid_`i' Conf_pos_`i' Conf_rpos_`i' Conf_rparty_`i' Conf_posXRpos_`i' Conf_pidXRpid_`i' Impt_pid_`i' Impt_pos_`i' Impt_rpos_`i' Impt_rparty_`i' Impt_posXRpos_`i' Impt_pidXRpid_`i' using "table4_robustness.out", 3aster se bracket tdec(3) replace 
 }
 else {
  outreg pos_`i' conf_`i' imp_`i' rpos_`i' rparty_`i' posXRpos_`i' pidXRpid_`i' Conf_pid_`i' Conf_pos_`i' Conf_rpos_`i' Conf_rparty_`i' Conf_posXRpos_`i' Conf_pidXRpid_`i' Impt_pid_`i' Impt_pos_`i' Impt_rpos_`i' Impt_rparty_`i' Impt_posXRpos_`i' Impt_pidXRpid_`i' using "table4_robustness.out", 3aster se bracket tdec(3) append 
 }

 *among those with strong opinions
 regress eval_`i' pos_`i' conf_`i' imp_`i' rpos_`i' rparty_`i' posXRpos_`i' pidXRpid_`i' Conf_pid_`i' Conf_pos_`i' Conf_rpos_`i' Conf_rparty_`i' Conf_posXRpos_`i' Conf_pidXRpid_`i' Impt_pid_`i' Impt_pos_`i' Impt_rpos_`i' Impt_rparty_`i' Impt_posXRpos_`i' Impt_pidXRpid_`i' `controlvars' if abs(pos_`i')==1 &  insample_`i'==1, robust
 outreg pos_`i' conf_`i' imp_`i' rpos_`i' rparty_`i' posXRpos_`i' pidXRpid_`i' Conf_pid_`i' Conf_pos_`i' Conf_rpos_`i' Conf_rparty_`i' Conf_posXRpos_`i' Conf_pidXRpid_`i' Impt_pid_`i' Impt_pos_`i' Impt_rpos_`i' Impt_rparty_`i' Impt_posXRpos_`i' Impt_pidXRpid_`i' using "table4_robustness.out", 3aster se bracket tdec(3) append 

 *among those with high importance
 regress eval_`i' pos_`i' conf_`i' rpos_`i' rparty_`i' posXRpos_`i' pidXRpid_`i' Conf_pid_`i' Conf_pos_`i' Conf_rpos_`i' Conf_rparty_`i' Conf_posXRpos_`i' Conf_pidXRpid_`i' `controlvars' if abs(imp_`i')==1 &  insample_`i'==1, robust
 outreg pos_`i' conf_`i' rpos_`i' rparty_`i' posXRpos_`i' pidXRpid_`i' Conf_pid_`i' Conf_pos_`i' Conf_rpos_`i' Conf_rparty_`i' Conf_posXRpos_`i' Conf_pidXRpid_`i' using "table4_robustness.out", 3aster se bracket tdec(3) append 

 ************************
 * Table A1. Summary Statistics for Model Variables and Coding Rules				
 ************************
 if "`i'"=="teen" {
  outsum eval_`i' pos_`i' conf_`i' imp_`i' `controlvars' if insample_`i'==1 using tableA1_sumstats, bracket replace ctitle("`1'")
 }
 else {
  outsum eval_`i' pos_`i' conf_`i' imp_`i' `controlvars' if insample_`i'==1 using tableA1_sumstats, bracket append ctitle("`1'")
 }
 * specify area for outcome label 
 label var eval_`i' "Eval of Rep.`1' (0-100)"

 *************************
 * Table A3. Manipulation Verification: Effect of Policy and Party Agreement on Representative Evaluation				
 *************************
set more 0
 ttest eval_`i' if insample_`i'==1, by(dich_agree_`i')
 if "`i'"=="teen"{
 local tableA3_diff="Policy Agreement - Policy Disagreement, "+string(r(mu_2)-r(mu_1))
 } 
 else{
 local tableA3_diff="`tableA3_diff', "+string(r(mu_2)-r(mu_1))
 }

 ttest eval_`i' if insample_`i'==1, by(dich_pty_agree_`i')
 if "`i'"=="teen"{
 local tableA3_ptydiff="Party Agreement - Party Disagreement, "+string(r(mu_2)-r(mu_1))
 } 
 else{
 local tableA3_ptydiff="`tableA3_ptydiff', "+string(r(mu_2)-r(mu_1))
 }
 if "`i'"=="bank"{
 * Write to CSV FILE
  file open myfile using "tableA3_differences.csv", write replace 
  file write myfile "Difference in Mean Evaluation,Teen Pregnancy,Same Sex Marriage,Job Creation,Banking Regulation" _n
   file write myfile "`tableA3_diff'" _n
   file write myfile "`tableA3_ptydiff'" _n
   file close myfile
 }

 ************************
 * Table A5. Effect of Party and Policy Agreement on Representative Evaluation, OLS Regression
 ************************
  regress eval_`i' pos_`i' rpos_`i' rparty_`i' posXRpos_`i' pidXRpid_`i' `controlvars' if insample_`i'==1, robust
 if "`i'"=="teen" {
  outreg using "tableA5_no_confimp_interactions.out", 3aster se bracket tdec(3) replace 
 }
 else {
  outreg using "tableA5_no_confimp_interactions.out", 3aster se bracket tdec(3) append 
 }

 ************************
 * Table A9. Predicting Policy Confidence, OLS Regression												 
 ************************
 regress conf_`i' age female educ income incomemis r_black r_hispanic r_other if insample_`i'==1, robust
 if "`i'"=="teen" {
  outreg using "tableA9_predict_conf.out", se bracket tdec(3) replace ctitle("Conf. (0-1) `i'") 
 }
 else {
  outreg using "tableA9_predict_conf.out", se bracket tdec(3) append ctitle("Conf. (0-1) `i'")
 }

 regress conf_`i' age female educ income incomemis r_black r_hispanic r_other if abspos_teen==1 & insample_`i'==1, robust
 outreg using "tableA9_predict_conf.out", se bracket tdec(3) append ctitle("Conf. (0-1) `i'")

 regress conf_`i' age female educ income incomemis r_black r_hispanic r_other pidcat_* if insample_`i'==1, robust
 outreg using "tableA9_predict_conf.out", se bracket tdec(3) append ctitle("Conf. (0-1) `i'")

 mac shift
}

 ************************
 * Table A8. Teen Pregnancy and Same Sex Marriage Opinions for Entire Sample and by Policy Confidence and Importance				
 ************************
foreach i in teen ssex{
  sum pos_`i' if insample_`i'==1
  local mean_op_`i'=r(mean)
  sum pos_`i' if insample_`i'==1 & dich_conf_`i'==1
  local mean_op_hc_`i'=r(mean)
  sum pos_`i' if insample_`i'==1 & dich_imp_`i'==1
  local mean_op_hi_`i'=r(mean)
  sum pos_`i' if insample_`i'==1 & dich_conf_`i'==1 & dich_imp_`i'==1
  local mean_op_hboth_`i'=r(mean)
  tab pos_`i', gen(`i'_D_)
  gen extreme_`i'=`i'_D_1+`i'_D_5
  drop `i'_D_*
  sum extreme_`i' if insample_`i'==1
  local prop_ex_`i'=r(mean)
  sum extreme_`i' if insample_`i'==1
  local prop_ex_`i'=r(mean)
  sum extreme_`i' if insample_`i'==1 & dich_conf_`i'==1
  local prop_ex_hc_`i'=r(mean)
  sum extreme_`i' if insample_`i'==1 & dich_imp_`i'==1
  local prop_ex_hi_`i'=r(mean)
  sum extreme_`i' if insample_`i'==1 & dich_conf_`i'==1 & dich_imp_`i'==1
  local prop_ex_hboth_`i'=r(mean)
  drop extreme_*
}  
  file open myfile using "tableA8_opinions_by_conf_imp.csv", write replace 
   file write myfile ", Mean Opinion (+1=Support; -1=Oppose), Proportion Extreme Opinions (strongly support or oppose), Mean Opinion (+1=Support; -1=Oppose), Proportion Extreme Opinions (strongly support or oppose)" _n
   file write myfile "Entire sample, `mean_op_teen', `prop_ex_teen', `mean_op_ssex', `prop_ex_ssex'" _n
   file write myfile "High Confidence, `mean_op_hc_teen', `prop_ex_hc_teen', `mean_op_hc_ssex', `prop_ex_hc_ssex'" _n
   file write myfile "High Importance, `mean_op_hi_teen', `prop_ex_hi_teen', `mean_op_hi_ssex', `prop_ex_hi_ssex'" _n
   file write myfile "High Importance and High Confidence, `mean_op_hboth_teen', `prop_ex_hboth_teen', `mean_op_hboth_ssex', `prop_ex_hboth_ssex'" _n
  file close myfile

**********************************************************************************
*** WITHIN PERSON ANALYSIS *******************************************************
**********************************************************************************
 ************************
 * Table 5. (COLUMN 1) Within person across policy areas, effect of Policy Agreement on Representative Evaluation by Variation in Confidence, OLS Regression							
 ************************
*Predicting which domain people are most confident about
preserve
qui egen confmin=rmin(conf_teen conf_ssex conf_jobs conf_bank)
qui egen confmax=rmax(conf_teen conf_ssex conf_jobs conf_bank)
drop if confmax==confmin
* drop if non-unique max or min
gen q = (conf_teen==confmax) + (conf_ssex==confmax) + (conf_jobs==confmax) + (conf_bank==confmax)
drop if q>1
drop q
gen q = (conf_teen==confmin) + (conf_ssex==confmin) + (conf_jobs==confmin) + (conf_bank==confmin)
drop if q>1
drop q

* generate new variables
gen area1=""
gen area2=""
gen posXRpos1=.
gen posXRpos2=.
gen eval1=.
gen eval2=.

qui foreach i in teen ssex jobs bank {
 replace area1="`i'" if confmax==conf_`i'
 replace posXRpos1=posXRpos_`i' if confmax==conf_`i'
 replace eval1=eval_`i' if confmax==conf_`i'
 replace area2="`i'" if confmin==conf_`i'
 replace posXRpos2=posXRpos_`i' if confmin==conf_`i'
 replace eval2=eval_`i' if confmin==conf_`i' 
}

keep  area1 posXRpos1 eval1 area2 posXRpos2 eval2
gen unique_id=_n
reshape long eval posXRpos area, i(unique_id) j(max)
replace max=0 if max==2
label var max "Most Confident Policy Area"

qui foreach i in teen ssex jobs bank {
 gen areacat_`i'=(area=="`i'")
 label var areacat_`i' "Policy `i'"
 gen posXRpos_`i'=posXRpos*(area=="`i'")
 label var posXRpos_`i' "Policy Agreement `i' (-1=Dis. to 1=Agg.)"
}

gen max_posXRpos=max*posXRpos
label var max_posXRpos "Policy Agreement (-1=Dis. to 1=Agg.) x Most Confident Policy Area"

xtreg eval areacat_* posXRpos_* max max_posXRpos, fe i(unique_id) cluster(unique_id)
outreg max_posXRpos max using "table5_withinperson.out", se 3aster bracket replace tdec(3)
restore

*Stack data for remaining within person analysis

*Get a common sample that exists for all policy areas
qui foreach i in teen ssex jobs bank {
 regress eval_`i' pos_`i' conf_`i' imp_`i' rpos_`i' rparty_`i' posXRpos_`i' pidXRpid_`i' Conf_pid_`i' Conf_pos_`i' Conf_rpos_`i' Conf_rparty_`i' Conf_posXRpos_`i' Conf_pidXRpid_`i' `controlvars', robust
 keep if e(sample)
}

*Demean confidence and importance
qui egen confmean=rmean(conf_teen conf_ssex conf_jobs conf_bank)
qui egen impmean=rmean(imp_teen imp_ssex imp_jobs imp_bank)
qui foreach i in teen ssex jobs bank {
 replace conf_`i'=conf_`i'-confmean
 replace imp_`i'=imp_`i'-impmean
 label var conf_`i' "Confidence rel. mean (0-1)"
 label var imp_`i' "Importance rel. mean (0-1)"
 label var pos_`i' "Position (+1=Supp.,-1=Opp.)"
 label var rparty_`i' "Rep's party (1=R, -1=D)"
 label var rpos_`i' "Rep's position (1=Supp, -1=Opp.)"
}

*Drop all confidence and importance interactions
drop Conf_* Impt_*

*Recode everything with demeaned confidence and importance
qui include 02_sub02_performcces_within_person_recodes

*generate unique id
gen uniqueid=_n

*now stack data
foreach i in teen ssex jobs bank {
 preserve
 keep r_black-incomemis uniqueid *_`i'
 foreach j of varlist *_`i' {
  local newname = substr("`j'",1,length("`j'")-5)
  rename `j' `newname'
  }
 gen area="`i'"
 if "`i'"=="teen" {
  save stacked.dta, replace
 }
 else {
  append using stacked.dta
  save stacked.dta, replace
 } 
 restore
}

clear
use stacked.dta

*now, create intereactions for effect of demographics across policy ares
qui foreach i in teen ssex jobs bank {
 foreach z in age age2 r_black r_hispanic r_other female educ income incomemis pid5 {
  local temp : variable label `z'
  gen DP`z'_`i'=`z'*(area=="`i'")
  label var DP`z'_`i' "`temp' X `i'"
 }
}

*and now interactions for everything else that isn't confidence
qui foreach i in teen ssex jobs bank {
 foreach z in pos conf imp rpos rparty posXRpos pidXRpid {
  local temp : variable label `z'
  gen PP`z'_`i'=`z'*(area=="`i'")
  label var PP`z'_`i' "`temp' X `i'"
 }
}

tab area, gen(areaindicator_)
drop areaindicator_4
label var eval "Support for Rep. (0-100)"

 ************************
 * Table 5. (COLUMNS 2-7) Within person across policy areas, effect of Policy Agreement on Representative Evaluation by Variation in Confidence, OLS Regression							
 ************************
regress eval pos conf imp rpos rparty posXRpos pidXRpid Conf_pid Conf_pos Conf_rpos Conf_rparty Conf_posXRpos Conf_pidXRpid Impt_pid Impt_pos Impt_rpos Impt_rparty Impt_posXRpos Impt_pidXRpid age age2 r_black r_hispanic r_other female pid5 educ income incomemis areaindicator_*, cluster(uniqueid)
outreg pos conf imp rpos rparty posXRpos pidXRpid Conf_pid Conf_pos Conf_rpos Conf_rparty Conf_posXRpos Conf_pidXRpid Impt_pid Impt_pos Impt_rpos Impt_rparty Impt_posXRpos Impt_pidXRpid using "table5_withinperson.out", se 3aster bracket append  tdec(3)
regress eval pos conf imp rpos rparty posXRpos pidXRpid Conf_pid Conf_pos Conf_rpos Conf_rparty Conf_posXRpos Conf_pidXRpid Impt_pid Impt_pos Impt_rpos Impt_rparty Impt_posXRpos Impt_pidXRpid areaindicator_* DP*, cluster(uniqueid)
outreg pos conf imp rpos rparty posXRpos pidXRpid Conf_pid Conf_pos Conf_rpos Conf_rparty Conf_posXRpos Conf_pidXRpid Impt_pid Impt_pos Impt_rpos Impt_rparty Impt_posXRpos Impt_pidXRpid using "table5_withinperson.out", se 3aster bracket append  tdec(3)
regress eval Conf_pid Conf_pos Conf_rpos Conf_rparty Conf_posXRpos Conf_pidXRpid Impt_pid Impt_pos Impt_rpos Impt_rparty Impt_posXRpos Impt_pidXRpid areaindicator_* DP* PP*, cluster(uniqueid)
outreg Conf_pid Conf_pos Conf_rpos Conf_rparty Conf_posXRpos Conf_pidXRpid Impt_pid Impt_pos Impt_rpos Impt_rparty Impt_posXRpos Impt_pidXRpid using "table5_withinperson.out", se 3aster bracket append  tdec(3)

xtreg eval pos conf imp rpos rparty posXRpos pidXRpid Conf_pid Conf_pos Conf_rpos Conf_rparty Conf_posXRpos Conf_pidXRpid Impt_pid Impt_pos Impt_rpos Impt_rparty Impt_posXRpos Impt_pidXRpid areaindicator_*, fe i(uniqueid) cluster(uniqueid)
outreg pos conf imp rpos rparty posXRpos pidXRpid Conf_pid Conf_pos Conf_rpos Conf_rparty Conf_posXRpos Conf_pidXRpid Impt_pid Impt_pos Impt_rpos Impt_rparty Impt_posXRpos Impt_pidXRpid using "table5_withinperson.out", se 3aster bracket append tdec(3)
xtreg eval pos conf imp rpos rparty posXRpos pidXRpid Conf_pid Conf_pos Conf_rpos Conf_rparty Conf_posXRpos Conf_pidXRpid Impt_pid Impt_pos Impt_rpos Impt_rparty Impt_posXRpos Impt_pidXRpid areaindicator_* DP*, fe i(uniqueid) cluster(uniqueid)
outreg pos conf imp rpos rparty posXRpos pidXRpid Conf_pid Conf_pos Conf_rpos Conf_rparty Conf_posXRpos Conf_pidXRpid Impt_pid Impt_pos Impt_rpos Impt_rparty Impt_posXRpos Impt_pidXRpid using "table5_withinperson.out", se 3aster bracket append tdec(3)
xtreg eval Conf_pid Conf_pos Conf_rpos Conf_rparty Conf_posXRpos Conf_pidXRpid Impt_pid Impt_pos Impt_rpos Impt_rparty Impt_posXRpos Impt_pidXRpid areaindicator_* DP* PP*, fe i(uniqueid) cluster(uniqueid)
outreg Conf_pid Conf_pos Conf_rpos Conf_rparty Conf_posXRpos Conf_pidXRpid Impt_pid Impt_pos Impt_rpos Impt_rparty Impt_posXRpos Impt_pidXRpid using "table5_withinperson.out", se 3aster bracket append tdec(3)

 ************************
 * RUN MECHANICAL TURK ANALYSIS
 ************************
qui include 02_sub03_performmturk_analysis.do

