***********************************************************************
***THIS FILE RECODES THE 2009 CCES DATA USED IN GERBER ET AL. (2012)***
***CITIZENS' POLICY CONFIDENCE AND ELECTORAL PUNISHMENT****************
***********************************************************************

*SAMPLE WEIGHTS
gen weight=v200

*** DEMOGRAPHICS
*Race
gen race=v211
tab race, gen(r_)
rename r_1 r_white
rename r_2 r_black
rename r_3 r_hispanic
gen r_other=r_4+r_5+r_6+r_7+r_8
label var r_white "White=1"
label var r_black "Black=1"
label var r_hispanic "Hispanic=1"
label var r_other "Other Race=1"

*Age
gen age=v288
gen age2=(age^2)/100
label var age "Age (in years)"
label var age2 "Age-squared/100"

*Gender
recode v208 (1=0) (2=1) (*=.), gen(female)
label var female "Female=1"

*PID
recode cc424 (1=-3) (2=-2) (3=-1) (5=1) (6=2) (7=3) (4 8=0) (*=.), gen(pid)
recode cc424 (1=-1) (2/3=-.5) (5/6=.5) (7=1) (4 8=0) (*=.), gen(pid5)
label var pid5 "5 Pt Party ID (-1=Dem; 1=Rep)"
tab pid5, gen(pidcat_)
drop pidcat_3
label var pidcat_1 "Strong Dem"
label var pidcat_2 "Weak/Lean Dem"
label var pidcat_4 "Weak/Lean Rep"
label var pidcat_5 "Strong Rep"

*Education
recode v213 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (*=.), gen(educ)
replace educ=(educ-1)/5
label var educ "Education (0 no HS; 1 postgrad)"

*Income
recode v246 (1=1) (2=2) (3=3) (4=4) (5=5) (6=6) (7=7) (8=8) (9=9) (10=10) (11=11) (12=12) (13=13) (14=14) (15=15) (*=.), gen(income)
replace income=(income-1)/14
label var income "Income (0=<$10k; .93=>150k; 1=Refused)"
gen incomemis=(income==1)
label var incomemis "Income Missing/Refused"


********************************
******EXPERIMENT VARIABLES******
********************************
*Individual's importance of issue
recode yal005 yal006 yal007 yal008 (1=0) (2=1) (3=2) (4=3) (*=.),gen(imp_teen imp_ssex imp_jobs imp_bank)
foreach var of varlist imp_teen imp_ssex imp_jobs imp_bank {
 replace `var'=`var'/3
 }

*Individual's position
recode yal009 yal010 yal011 yal012 (1=1) (2=2) (3=3) (4=4) (5=5) (*=.),gen(pos_teen pos_ssex pos_jobs pos_bank)
foreach var of varlist pos_teen pos_ssex pos_jobs pos_bank {
 replace `var'=(`var'-3)/2
 }

*Individual's confidence in position
recode yal013 yal014 yal015 yal016 yal017 yal018 yal019 yal020 (1=1) (2=2) (3=3) (4=4) (*=.),gen(conf1_teen conf1_ssex conf1_jobs conf1_bank conf2_teen conf2_ssex conf2_jobs conf2_bank)
foreach var of varlist conf1_teen conf1_ssex conf1_jobs conf1_bank conf2_teen conf2_ssex conf2_jobs conf2_bank {
 replace `var'=(`var'-1)/3
 }

*Average of two confidence measures
local list = "teen ssex jobs bank"
foreach var of local list {
 gen conf_`var'=(conf1_`var'+conf2_`var')/2
 }

*Evalation of Rep. on issue
recode yal121 yal122 yal123 yal124 (-1000/-.01=.) (101/.=.), gen(eval_teen eval_ssex eval_jobs eval_bank)

*Party of Rep in story, binary and -1, 1
local itemctr=1
foreach i in teen ssex jobs bank {
 gen rparty_`i'=.
 replace rparty_`i'=1 if yal12`itemctr'party=="Republican"
 replace rparty_`i'=-1 if yal12`itemctr'party=="Democrat"
 local itemctr=`itemctr'+1
}

*Position of Rep in story
local itemctr=1
foreach i in teen ssex jobs bank {
 gen rpos_`i'=.
 replace rpos_`i'=-1 if yal12`itemctr'position=="against"
 replace rpos_`i'=1 if yal12`itemctr'position=="for"
 local itemctr=`itemctr'+1
}

foreach i in teen ssex jobs bank{
 label var eval_`i' "Eval of Rep. (0-100)"
}

*tokenize `"" (Teen Pregnancy)"" (Same Sex Marriage)"" (Job Creation)"" (Banking Regulation)""'
tokenize `""""""""""'
foreach i in teen ssex jobs bank{

 *Begin by labeling previously created variables
 label var imp_`i' "Importance`1' (0-1)"
 label var pos_`i' "Position`1' (+1=Supp.,-1=Opp.)"
 label var conf_`i' "Confidence in pol. choice`1' (0-1)"
 label var rparty_`i' "Rep.'s party`1' (1=R, -1=D)"
 label var rpos_`i' "Rep.'s position`1' (1=Supp, -1=Opp.)"

 *For analysis of sources of opinions, construct absolute value of policy opinion
 gen abspos_`i'=abs(pos_`i')
 label var abspos_`i' "Abs. Value Position`1' (+1=Supp. or Opp., 0=No Opinon.)"

 *Create agreement interactions
 
 *Policy agreement
 gen posXRpos_`i' =  pos_`i'*rpos_`i'
 label var posXRpos_`i' "Policy agreement`1' (-1=Dis. to 1=Agg.)"
 
 *Party agreement
 gen pidXRpid_`i' = pid5*rparty_`i'
 label var pidXRpid_`i' "Party agreement`1' (-1 to 1)"

 *Party x Policy Agreement
 gen Zbothagree_`i'= pidXRpid_`i'*posXRpos_`i'
 label var Zbothagree_`i' "Party X Policy agreement`1' (-1 to 1)"

 *Importance Interactions
 gen Impt_pid_`i' = pid5 * imp_`i'
 label var Impt_pid_`i' "Impt. X PID`1' (-1 to 1)"

 gen Impt_pos_`i' = pos_`i' * imp_`i'
 label var Impt_pos_`i' "Impt. X Position`1' (-1 to 1)"

 gen Impt_rpos_`i' = rpos_`i' * imp_`i'
 label var Impt_rpos_`i' "Impt. X Rep.'s position`1' (0-1)"

 gen Impt_rparty_`i' = rparty_`i' * imp_`i'
 label var Impt_rparty_`i' "Impt. X Rep.'s party`1' (-1 to 1)"

 gen Impt_posXRpos_`i' = posXRpos_`i' * imp_`i'
 label var Impt_posXRpos_`i' "Impt. X Policy Agreement`1' (-1=Dis. to 1=Agg.)"
 
 gen Impt_pidXRpid_`i' = pidXRpid_`i'  * imp_`i'
 label var Impt_pidXRpid_`i' "Impt. X Party agreement`1' (-1 to 1)"

 gen Impt_Zbothagree_`i' = Zbothagree_`i'  * imp_`i'
 label var Impt_Zbothagree_`i' "Impt. X Party x Policy agreement`1' (-1 to 1)"
 
 *Agreement (Party and Policy) * Confidence
 gen Conf_pid_`i' = pid5 * conf_`i'
 label var Conf_pid_`i' "Conf. X PID`1' (-1 to 1)"

 gen Conf_pos_`i' = pos_`i' * conf_`i'
 label var Conf_pos_`i' "Conf. X Position`1' (-1 to 1)"

 gen Conf_rpos_`i' = rpos_`i' * conf_`i'
 label var Conf_rpos_`i' "Conf. X Rep.'s position`1' (0-1)"

 gen Conf_rparty_`i' = rparty_`i' * conf_`i'
 label var Conf_rparty_`i' "Conf. X Rep.'s party`1' (-1 to 1)"

 gen Conf_posXRpos_`i' = posXRpos_`i' * conf_`i'
 label var Conf_posXRpos_`i' "Conf. X Policy Agreement`1' (-1=Dis. to 1=Agg.)"
 
 gen Conf_pidXRpid_`i' = pidXRpid_`i'  * conf_`i'
 label var Conf_pidXRpid_`i' "Conf. X Party agreement`1' (-1 to 1)"

 gen Conf_Zbothagree_`i' = Zbothagree_`i' * conf_`i'
 label var Conf_Zbothagree_`i' "Conf. X Party x Policy agreement`1' (-1 to 1)"

 *4 Way interactions
 *First, confidence * Importance
 gen ConfImpt_`i'=imp_`i'*conf_`i'
 label var ConfImpt_`i' "Importance x Confidence`1' (0 to 1)"

 gen FW_pid_`i' = pid5 * ConfImpt_`i'
 label var FW_pid_`i' "Conf. X Impt. X PID (-1 to 1)

 gen FW_pos_`i' = pos_`i' * ConfImpt_`i'
 label var FW_pos_`i' "Conf. X Impt. X Position`1' (-1 to 1)

 gen FW_rpos_`i' = rpos_`i' * ConfImpt_`i'
 label var FW_rpos_`i' "Conf. X Impt. X Rep.'s position`1' (0-1)"

 gen FW_rparty_`i' = rparty_`i' * ConfImpt_`i'
 label var FW_rparty_`i' "Conf. X Impt. X Rep.'s party`1' (-1 to 1)"
 
 gen FW_posXRpos_`i' = posXRpos_`i' * ConfImpt_`i'
 label var FW_posXRpos_`i' "Conf. X Impt. X Policy Agreement`1' (-1=Dis. to 1=Agg.)"
 
 gen FW_pidXRpid_`i' = pidXRpid_`i'  * ConfImpt_`i'
 label var FW_pidXRpid_`i' "Conf. X Impt. X Party agreement`1' (-1 to 1)"

 gen FW_Zbothagree_`i' = Zbothagree_`i' * ConfImpt_`i'
 label var FW_Zbothagree_`i' "Conf. X Impt. X Party x Policy agreement`1' (-1 to 1)"

 *all the other covariates mutiplied by policy agreement
 qui foreach z in age age2 r_black r_hispanic r_other female educ income incomemis {
  local temp : variable label `z'
  gen Q`z'_polmatch_`i'=`z' * posXRpos_`i'
  label var Q`z'_polmatch_`i' "`temp' X Policy Agreement`1' (-1=Dis. to 1=Agg.)"
 }
 
 mac shift 
}

