********************************************************************************
***THIS FILE GENERATES THE MECHANICAL TURK ANALYSIS REPORTED IN*****************
***GERBER ET AL. (2012): CITIZENS' POLICY CONFIDENCE AND ELECTORAL PUNISHMENT***
********************************************************************************

use mturk_replication.dta, clear

** DEMOGRAPHICS
egen pid5=rmean(pid_dstr pid_rstr pid_lean)
recode pid5 (-3=-2) (-2 -1=-1) (0=0) (1 2=1) (3=2)
label var pid5 "Party ID (-1=S Dem; 1=S Rep)"
gen age=2010-year_of_birth
label var age "Age (in years)"
gen age2=(age*age)/100
label var age2 "Age-squared/100"
label var educ "Education (1=No HS; 6=post-grad)"
gen incomemis=(income==15)
replace income=14 if incomemis==1
label var income "Income (1=<10k; 14=150k+/RF)"
label var incomemis "Income missing"
replace r_white=0 if r_white==.
replace r_white=1 if r_white!=0
label var r_white "White = 1"
gen female=gender
label var female "Female=1"

label var eval_ssex "Same Sex Marriage"
label var eval_nuclear "Nuclear Power"
label var eval_abortion "Abortion Rule Change"
label var eval_captax "Capital Gains"

foreach i in ssex nuclear abortion captax{
gen agree_`i'=supp_`i'*cond_`i'
label var agree_`i' "Policy Agreement (-2 to 2)"
}
replace efficacy=efficacy-4
foreach i in ssex nuclear abortion captax{
gen eff_agr`i'=efficacy*agree_`i'
}

 ************************
 * Table A7. Effect of Policy Agreement on Representative Evaluation by Variation in Political Efficacy, OLS Regression				
 ************************
label var efficacy "Internal Efficacy (-3 to 3)"
foreach i in ssex nuclear abortion captax{
label var eff_agr`i' "Internal Efficacy x Agreement"
reg eval_`i' agree_`i' efficacy eff_agr`i' age age2 r_white female pid5 educ income incomemis, r
if "`i'"=="ssex"{
outreg  agree_`i' efficacy eff_agr`i' age age2 r_white female pid5 educ income incomemis using "logs\tableA7_efficacy", se bracket 3aster replace tdec(3)
}
else{
outreg agree_`i' efficacy eff_agr`i' age age2 r_white female pid5 educ income incomemis using "logs\tableA7_efficacy", se bracket 3aster append tdec(3)
}
}
